##########
Change Log
##########

All notable changes to this project are documented in this file.


==================
2.0.0 - 2023-06-21
==================

Added
-----
- Implementation of the following methods:

    - CPM
    - FPKM
    - TPM
    - UQ
    - CUF
    - TMM
    - CTF

- Add a "toy" and GTEx dataset
- Add command line interface for all of the above methods
- Add tests
- Support calculation of gene lengths from GTf or gene lengths file in TPM /
  FPKM
